-------------------------------------------------------------------------------------
-- Entity:	Dx64Header
--
-- Project:	Uni1p
--
-- Author:	Antonin Hegar
--
-- Description:
--	Package for system entity.
--
-- Revision:
--	$Log: Dx64Header.vhd,v $
--	Revision 1.5  2006/04/12 05:32:01  Tony
--	Added constants for DSP and INPUT clock frequency.
--	
--	Revision 1.4  2006/02/02 17:03:10  Tony
--	Interrupt mask register (FPGA_VALID) added.
--	
--	Revision 1.3  2006/01/24 21:01:12  Tony
--	MemoryPort component support is added.
--	
--	Revision 1.2  2005/05/03 17:37:55  Tony
--	no message
--	
--	Revision 1.1  2004/10/16 21:11:17  Tony
--	Initial release.
--	
--
--
-------------------------------------------------------------------------------------

-------------------------------------------------------------------------------------
-- LIBRARY
-------------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use work.MathLib.all;

-------------------------------------------------------------------------------------
-- PACKAGE
-------------------------------------------------------------------------------------
package Dx64Header is

	-- input clock frequency 
	constant INPUT_CLOCK_FREQ_C		: natural := 50e6;
    -- DSP clock frequency
    constant DSP_CLOCK_FREQ_C       : natural := 50e6;

	---------------------------------------------------------------------------------
	-- EMIFB
	---------------------------------------------------------------------------------
	-- FPGA clock frequency BECLKOUT
	constant FPGA_CLOCK_FREQ_C		: natural := 50e6;

	constant DX64_DATA_WIDTH_C		: natural := 16;					-- width of EMIFB data bus
	constant DX64_ADDR_WIDTH_C		: natural := 8;						-- width of EMIFB address bus

	constant DSP_DATA_WIDTH_C		: natural := 16;					-- width of internal data bus
	constant DSP_ADDR_WIDTH_C		: natural := 8;						-- width of internal address bus

-- 	constant LB_REGISTER_LOW_C		: natural := 0;                     -- bottom and top index of
-- 	constant LB_REGISTER_HIGH_C		: natural := 3;						-- local addr bus to decode register
-- 	constant LB_DEVICE_LOW_C		: natural := LB_REGISTER_HIGH_C+1;	-- bottom and top index of
-- 	constant LB_DEVICE_HIGH_C		: natural := LB_ADDR_WIDTH_C-1;		-- local addr bus to decode device

	---------------------------------------------------------------------------------
	-- Local Bus interface type to DSP
	type DspBus_T is record
		DataIn		: unsigned(DSP_DATA_WIDTH_C-1 downto 0);			-- input data bus
		DataOut		: unsigned(DSP_DATA_WIDTH_C-1 downto 0);			-- output data bus (it's drive
																		-- by zeros when device isn't addressed
		Addr		: unsigned(DSP_ADDR_WIDTH_C-1 downto 0);			-- input address
		Write		: std_logic;										-- write signal (active high)
		Read		: std_logic;                                      	-- read signal (active high)
	end record;

	-- local bus array
	type DspBusArr_T is array ( natural range <>) of DspBus_T;


	-- NMI pulse length
	constant NMI_PULSE_LEN_C		: natural := 2 + (10*FPGA_CLOCK_FREQ_C)/DSP_CLOCK_FREQ_C;
	-- DRESET pulse length
	constant DRESET_PULSE_LEN_C		: natural := 1 + FPGA_CLOCK_FREQ_C / 4000;


	---------------------------------------------------------------------------------
	-- CE1 address space
	-- register address
    constant BRAM_SIZE_BITS_C               : natural := 16384;

    
	constant DX64_REG_CTRL_C		        : natural := 0;

    type MemoryPortChain_T is record    
        SectorReady     : std_logic;
        SectorOvf       : std_logic;
    end record;
    type MemoryPortChainArr_T is array (natural range<>) of MemoryPortChain_T;
    constant LAST_MEM_PORT_C                : MemoryPortChain_T := ( '0', '0' );

    
    -- maximum number of sectors in system
    constant MEMPORT_MAX_SECTORS_C          : natural := 32;
    -- size of the sector in halfwords
    constant MEMPORT_SECTOR_SIZE_C          : natural := 512;
    constant MEMPORT_SECTOR_WIDTH_C         : natural := log2( MEMPORT_SECTOR_SIZE_C-1 );
    
    constant MEMPORT_ADDR_LOW_ADDR_C        : natural := 16;
    constant MEMPORT_ADDR_HIGH_ADDR_C       : natural := 17;    
    constant MEMPORT_READY_LOW_ADDR_C   	: natural := 18;
    constant MEMPORT_READY_HIGH_ADDR_C 	 	: natural := 19;
    constant MEMPORT_OVF_LOW_ADDR_C    		: natural := 22;
    constant MEMPORT_OVF_HIGH_ADDR_C   		: natural := 23;
    constant MEMPORT_DATA_LOW_ADDR_C        : natural := 24;
    constant MEMPORT_DATA_HIGH_ADDR_C       : natural := 25;
    constant MEMPORT_MASK_LOW_ADDR_C   		: natural := 26;
    constant MEMPORT_MASK_HIGH_ADDR_C  		: natural := 27;
    
        
end package Dx64Header;
